
..
    # This file has been generated by ansible-doc-template-extractor.
    # Do not modify this file manually, but modify its spec file source!

.. _storage_host_create_role:

Role storage_host_create -- Ensure that a host on a storage system exists and has host WWPNs.
=============================================================================================

Synopsis
--------

Ensure that a host on a storage system exists and has host WWPNs.


This role is idempotent.



Input Parameters
----------------

* **sys_hostname** (str):

  IP address or hostname of the storage system for logging in.


  Required.

* **sys_username** (str):

  Username on the storage system.


  Required.

* **sys_password** (str):

  Password on the storage system.


  Required.

* **host_name** (str):

  Name of the host to be created.


  Required.

* **host_wwpns** (list of str):

  WWPNs for the host, in :literal:`hh:hh...` or :literal:`hhhh...` format.


  Required.



Output Parameters
-----------------

* **host_info** (dict):

  Properties of the host (specific to :literal:`sar\_type`\ ).


  Required.



Local Variables
---------------

* **_foo** (object):

  


  Optional.



Examples
--------

* Example for invoking the role



  .. code-block:: bash

      tasks:
      
        - name: "Ensure host object exists on storage system"
          vars:
            sys_hostname: "10.11.12.13"
            sys_username: myuser
            sys_password: mypwd
            host_name: "host1"
            host_wwpns: "aa.bb.cc...."
          include_role:
            name: storage_host_create
      
        - name: "Debug host info"
          debug:
            var: host_info



Authors
-------

* Andreas Maier
